@@ -13,16 +13,6 @@
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
-/**
- * 携帯用ドキュメントタイプ取得
- *
- * @return 						なし
- */
-function m3MobileDocType()
-{
-	global $gPageManager;
-	$gPageManager->getMobileDocType();
-}
 /**
  * ウィジェット埋め込み
  *
