@@ -30,7 +30,8 @@ INSERT INTO content_config
 ('smartphone', 'head_view_detail', '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_DESCRIPTION#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'HTMLヘッダ(詳細表示)',               3),
 ('',           'use_jquery',      '0', 'jQueryスクリプト作成', 0),
 ('smartphone', 'use_jquery',      '0', 'jQueryスクリプト作成', 0),
-('',           'use_content_template',      '0', 'コンテンツ単位のテンプレート設定', 0);
+('',           'use_content_template',      '0', 'コンテンツ単位のテンプレート設定', 0),
+('',           'auto_generate_attach_file_list',      '1', '添付ファイルリストを自動作成', 0);
 
 -- 新着情報設定マスター
 INSERT INTO news_config
@@ -127,11 +128,6 @@ VALUES                 ('auto_email_sender',       '',          '自動送信メ
 INSERT INTO `bbs_group` (`sg_id`, `sg_language_id`, `sg_name`, `sg_sort_order`, `sg_editable`, `sg_create_dt`) VALUES
 (1,    'ja',           'ゲスト',        1,   false,   now());
 
--- ユーザコンテンツ項目マスター
-INSERT INTO user_content_item
-(ui_id,          ui_name,      ui_description,                   ui_type,  ui_key,        ui_create_dt) VALUES
-('DEFAULT_LIST', '検索一覧用', '検索結果の一覧に表示するデータ', 0,        'SEARCH_LIST', now());
-
 -- 予約リソースマスター
 INSERT INTO reserve_resource (rr_id, rr_type, rr_config_id, rr_name, rr_sort_order)
 VALUES                       (1,     0,       0,            'デフォルト', 1);
@@ -231,34 +227,33 @@ VALUES                 ('regist_user_completed', 'ja',           'ユーザ自
 DELETE FROM _mail_form WHERE mf_id = 'send_tmp_password';
 INSERT INTO _mail_form (mf_id,           mf_language_id, mf_subject,         mf_content,                                                                 mf_create_dt) 
 VALUES                 ('send_tmp_password', 'ja',           '仮パスワード送信', '仮パスワードを送信します。\nこのパスワードでログインし、パスワードを再設定してください。\n\nパスワード　[#PASSWORD#]',                               now());
+DELETE FROM _mail_form WHERE mf_id = 'skyway_call';
+INSERT INTO _mail_form (mf_id,           mf_language_id, mf_subject,         mf_content,                                                                 mf_create_dt) 
+VALUES                 ('skyway_call', 'ja',              'SkyWay呼び出し応答用',     'SkyWay呼び出しがありました。以下のURLにアクセスすると応答できます。\n\n[#URL#]',                             now());
 
 -- テンプレート情報
 TRUNCATE TABLE _templates;
 INSERT INTO _templates
-(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_mobile, tm_use_bootstrap, tm_available, tm_generator, tm_version, tm_info_url) VALUES
-('_admin',                       '_admin',                         2,       0,              false,     true,             false,        '',           '',         ''),
-('_system',                       '_system',                       1,       0,              false,     false,            false,        '',           '',         ''),
-('_layout',                       '_layout',                       1,       0,              false,     false,            false,        '',           '',         ''),
-('art41_sample1',                 'art41_sample1',                 2,       0,              false,     false,            true,         '',           '',         ''),
-('art41_sample2',                 'art41_sample2',                 2,       0,              false,     false,            true,         '',           '',         ''),
-('art42_sample3',                 'art42_sample3',                 2,       0,              false,     false,            true,         '',           '',         ''),
-('art42_sample4',                 'art42_sample4',                 2,       0,              false,     false,            true,         '',           '',         ''),
-('art42_sample5',                 'art42_sample5',                 2,       0,              false,     false,            true,         '',           '',         ''),
-('themler_sample0',               'themler_sample0',               2,       0,              false,     false,            true,         'themler',    '1.0.220',  ''),
-('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,     true,             true,         '',           '',         ''),
-('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,     true,             true,         '',           '',         ''),
-('bootstrap_united',              'bootstrap_united',              10,      0,              false,     true,             true,         '',           '',         ''),
-('bootstrap_cerulean_head',       'bootstrap_cerulean_head',       10,      0,              false,     true,             true,         '',           '',         ''),
-('bs_honoka3',                    'bs_honoka3',                    10,       0,             false,     true,             true,         '',           '',         'http://honokak.osaka/'),
-('bs_single_gray',                'bs_single_gray',                10,       0,             false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/grayscale/'),
-('bs_single_orange',              'bs_single_orange',              10,       0,             false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/creative/'),
-('wisteria',                      'wisteria',                      100,      0,             false,     false,            true,         '',           '',         'https://wpfriendship.com/'),
-('m/default',                     'm/default',                     0,       1,              true,      false,            true,         '',           '',         ''),
-('m/smallfont',                   'm/smallfont',                   0,       1,              true,      false,            true,         '',           '',         ''),
-('s/default_simple',              's/default_simple',              1,       2,              false,     false,            true,         '',           '',         ''),
-('s/default_jquery',              's/default_jquery',              1,       2,              false,     false,            true,         '',           '',         ''),
-('s/default_jquery13',           's/default_jquery13',             1,       2,              false,     false,            true,         '',           '',         ''),
-('s/art42_sample2',               's/art42_sample2',               1,       2,              false,     false,            true,         '',           '',         '');
+(tm_id,                           tm_name,                         tm_type, tm_device_type, tm_has_admin, tm_mobile, tm_use_bootstrap, tm_available, tm_generator, tm_version, tm_info_url) VALUES
+('_admin',                       '_admin',                         2,       0,              false,        false,     true,             false,        '',           '',         ''),
+('_system',                       '_system',                       1,       0,              false,        false,     false,            false,        '',           '',         ''),
+('_layout',                       '_layout',                       99,      0,              false,        false,     false,            false,        '',           '',         ''),
+('art42_sample3',                 'art42_sample3',                 2,       0,              false,        false,     false,            true,         '',           '',         ''),
+('art42_sample5',                 'art42_sample5',                 2,       0,              false,        false,     false,            true,         '',           '',         ''),
+('themler_sample0',               'themler_sample0',               2,       0,              false,        false,     false,            true,         'themler',    '1.0.220',  ''),
+('themler_old',                   'themler_old',                   2,       0,              false,        false,     false,            true,         'themler',    '1.0.68',   ''),
+('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,        false,     true,             true,         '',           '',         ''),
+('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,        false,     true,             true,         '',           '',         ''),
+('bootstrap_united',              'bootstrap_united',              10,      0,              false,        false,     true,             true,         '',           '',         ''),
+('bootstrap_cerulean_head',       'bootstrap_cerulean_head',       10,      0,              false,        false,     true,             true,         '',           '',         ''),
+('bootstrap4_custom',             'bootstrap4_custom',             11,      0,              true,         false,     true,             true,         '',           '',         ''),
+('bs_honoka3',                    'bs_honoka3',                    10,      0,              false,        false,     true,             true,         '',           '',         'http://honokak.osaka/'),
+('bs_single_gray',                'bs_single_gray',                10,      0,              false,        false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/grayscale/'),
+('bs_single_orange',              'bs_single_orange',              10,      0,              false,        false,     true,             true,         '',           '',         'https://startbootstrap.com/template-overviews/creative/'),
+('wisteria',                      'wisteria',                      100,     0,              false,        false,     false,            true,         '',           '',         'https://wpfriendship.com/'),
+('shop-isle',                     'shop-isle',                     100,     0,              false,        false,     false,            true,         '',           '',         'https://themeisle.com/'),
+('s/default_simple',              's/default_simple',              1,       2,              false,        false,     false,            true,         '',           '',         ''),
+('s/art42_sample2',               's/art42_sample2',               1,       2,              false,        false,     false,            true,         '',           '',         '');
 
 -- メニューIDマスター
 INSERT INTO _menu_id
@@ -267,7 +262,6 @@ INSERT INTO _menu_id
 ('sub_menu1',   'サブメニュー1',  '',             0,        '',      1),
 ('sub_menu2',   'サブメニュー2',  '',             0,        '',      2),
 ('sub_menu3',   'サブメニュー3',  '',             0,        '',      3),
-('m_main_menu', 'メインメニュー(携帯用)', '',             1,      '',        10),
 ('s_main_menu', 'メインメニュー(スマートフォン用)', '',             2,     '',         0);
 
 -- 基本テーブルの不要なデータを削除
@@ -356,30 +350,6 @@ INSERT INTO bbs_2ch_config
 ('msg_thread_end',        'このスレッドは${maxnum}を超えました。 <br /> もう書けないので、新しいスレッドを立ててくださいです。。。 ', 'スレッドの終了メッセージ'),
 ('thread_end_message',    'このスレッドは[#RES_MAX_NO#]を超えました。\r\nもう書けないので、新しいスレッドを立ててくださいです。。。', 'スレッドの終了メッセージ');
 
--- --------------------------------------------------------------------------------------------------
--- マイクロブログウィジェット用
--- --------------------------------------------------------------------------------------------------
-INSERT INTO mblog_config 
-(mc_id,                   mc_value,                mc_name) VALUES
-('post_with_no_login',    '0',                     'ログインなしの投稿'),
-('use_subject',           '0',                     '件名の使用'),
-('message_id_length',     '5',                     'メッセージIDのバイト数'),
-('message_count_top',     '3',                     'トップページのメッセージ表示項目数'),
-('message_count_mypage',  '30',                    'マイページのメッセージ表示項目数'),
-('m:message_count_mypage','10',                    'マイページのメッセージ表示項目数(携帯)'),
-('text_color',            '#000000',               '文字色'),
-('bg_color',              '#EAF4F5',               '背景色'),
-('inner_bg_color',        '#FFFFCC',               '内枠のデフォルト背景色'),
-('profile_color',         '',                      'プロフィール背景色'),
-('err_message_color',     '#FF0000',               'エラーメッセージ文字色'),
-('bg_image',              '',                      '背景画像'),
-('message_length',         '200',                   '投稿文最大長'),
-('subject_length',         '30',                   '件名最大長'),
-('name_length',            '30',                   '投稿者名最大長'),
-('email_length',           '30',                   'emailアドレス最大長'),
-('top_contents',           '',                     'トップ画面のコンテンツ'),
-('m:top_contents',           '',                   'トップ画面のコンテンツ(携帯)');
-
 -- --------------------------------------------------------------------------------------------------
 -- イベント情報用
 -- --------------------------------------------------------------------------------------------------
@@ -456,97 +426,6 @@ INSERT INTO photo_config
 ('output_head',      '0', 'HTMLヘッダ出力', 0),
 ('head_view_detail',   '<meta property="og:type" content="article" /><meta property="og:title" content="[#CT_TITLE#]" /><meta property="og:url" content="[#CT_URL#]" /><meta property="og:image" content="[#CT_IMAGE#]" /><meta property="og:description" content="[#CT_SUMMARY#]" /><meta property="og:site_name" content="[#SITE_NAME#]" />', 'ヘッダ出力(詳細表示)',               0);
 
--- --------------------------------------------------------------------------------------------------
--- 携帯クイズ王ウィジェット用
--- --------------------------------------------------------------------------------------------------
--- クイズ設定マスター
-DROP TABLE IF EXISTS quiz_config;
-CREATE TABLE quiz_config (
-    qc_id                VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ID(Key)
-    qc_value             TEXT                                         NOT NULL,      -- 値
-    qc_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 名称
-    qc_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
-    qc_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
-    PRIMARY KEY          (qc_id)
-) ENGINE=innodb;
-
--- クイズパターンセットIDマスター
-DROP TABLE IF EXISTS quiz_set_id;
-CREATE TABLE quiz_set_id (
-    qs_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
-    qs_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 定義項目ID
-    qs_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
-
-    qs_name              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 名称
-    qs_description       VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 説明
-    qs_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
-    qs_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示制御
-    
-    qs_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
-    qs_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    qs_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    qs_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    qs_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
-    PRIMARY KEY          (qs_serial),
-    UNIQUE               (qs_id,  qs_history_index)
-) ENGINE=innodb;
-
--- クイズ問題定義マスター
-DROP TABLE IF EXISTS quiz_item_def;
-CREATE TABLE quiz_item_def (
-    qd_serial            INT            AUTO_INCREMENT,                              -- シリアル番号
-    qd_set_id            VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 定義セットID
-    qd_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- クイズ項目(問題、回答)ID
-    qd_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
-
-    qd_type              INT            DEFAULT 0                     NOT NULL,      -- 項目タイプ(0=問題、1=回答)
-    qd_select_answer_id  TEXT                                         NOT NULL,      -- 選択用回答ID
-    qd_answer_id         VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 正解回答ID
-    qd_title             VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- タイトル
-    qd_content           VARCHAR(300)   DEFAULT ''                    NOT NULL,      -- 内容
-    qd_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
-    qd_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示制御
-    
-    qd_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
-    qd_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
-    qd_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
-    qd_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
-    qd_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
-    PRIMARY KEY          (qd_serial),
-    UNIQUE               (qd_set_id,   qd_id,  qd_history_index)
-) ENGINE=innodb;
-
--- クイズユーザ回答トラン
-DROP TABLE IF EXISTS quiz_user_post;
-CREATE TABLE quiz_user_post (
-    qp_serial            INT            AUTO_INCREMENT,                              -- シリアル番号
-    qp_mobile_id         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 携帯端末ID
-    qp_set_id            VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 定義セットID
-    qp_question_id       VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- クイズ問題ID
-    qp_answer_id         VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 回答ID
-    qp_result            BOOLEAN        DEFAULT false                 NOT NULL,      -- 回答結果
-    qp_dt                TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 記録日時
-    qp_access_log_serial INT            DEFAULT 0                     NOT NULL,      -- アクセスログ番号
-    PRIMARY KEY          (qp_serial),
-    UNIQUE               (qp_mobile_id,   qp_set_id,  qp_question_id)
-) ENGINE=innodb;
-
-INSERT INTO quiz_set_id (qs_id,         qs_name,              qs_index)
-VALUES                  ('default_set', 'デフォルトパターン', 0);
-INSERT INTO quiz_config (qc_id,            qc_value,      qc_name,                        qc_index)
-VALUES                  ('current_set_id', 'default_set', '現在運用中のパターンセットID', 0);
--- サンプルデータ
-INSERT INTO quiz_item_def
-(qd_set_id,      qd_id, qd_type, qd_select_answer_id, qd_answer_id, qd_title, qd_content,            qd_index) VALUES
-('default_set', 'A001', 1,       '',                  '',           '回答1',  '回答1の説明です。',   0),
-('default_set', 'A002', 1,       '',                  '',           '回答2',  '回答2の説明です。',   0),
-('default_set', 'A003', 1,       '',                  '',           '回答3',  '回答3の説明です。',   0),
-('default_set', 'A004', 1,       '',                  '',           '回答4',  '回答4の説明です。',   0),
-('default_set', 'A005', 1,       '',                  '',           '回答5',  '回答5の説明です。',   0),
-('default_set', 'A006', 1,       '',                  '',           '回答6',  '回答6の説明です。',   0),
-('default_set', 'Q001', 0,       'A001;A002;A003',    'A002',       '問題1',  'サンプル問題1です。', 1),
-('default_set', 'Q002', 0,       'A006;A004;A005',    'A006',       '問題2',  'サンプル問題2です。', 2);
-
 -- --------------------------------------------------------------------------------------------------
 -- 以下、変更の少ないデータ
 -- --------------------------------------------------------------------------------------------------
