@@ -484,6 +484,10 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					}
 				}
 				
+				// 画像のパスをマクロ表現に変換
+				$html = $this->gInstance->getTextConvManager()->convToContentMacro($html);
+				$html2 = $this->gInstance->getTextConvManager()->convToContentMacro($html2);
+				
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
 										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
@@ -613,6 +617,10 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					}
 				}
 
+				// 画像のパスをマクロ表現に変換
+				$html = $this->gInstance->getTextConvManager()->convToContentMacro($html);
+				$html2 = $this->gInstance->getTextConvManager()->convToContentMacro($html2);
+				
 				// 追加パラメータ
 				$otherParams = array(	'be_description'		=> $desc,		// 簡易説明
 										'be_meta_description'	=> $metaDesc,		// ページ要約(METAタグ)
