@@ -250,7 +250,7 @@ class contactusWidgetContainer extends BaseWidgetContainer
 		}
 		// HTMLサブタイトルを設定
 //		$this->gPage->setHeadSubTitle(self::DEFAULT_TITLE_NAME);
-		$this->gPage->setHeadSubTitle();			// 共通設定画面の「タイトル」値を使用する
+		$this->gPage->setHeadSubTitle($this->gEnv->getCurrentWidgetHeadTitle());			// 共通設定画面の「タイトル」値を使用する
 			
 		// タイトルの表示
 		if ($showTitle){
