@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2016 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_menuMenudefWidgetContainer.php 5412 2012-11-25 13:30:30Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_ec_menuBaseWidgetContainer.php');
@@ -34,6 +34,9 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 	private $categoryListData;		// 商品カテゴリー
 	private $categoryArray;			// カテゴリー設定値
 	private $catagorySelectCount;	// カテゴリー選択可能数
+	private $parentId;				// メニュー親項目
+	private $parentIdArray = array();			// メニュー項目パス
+	private $parentNameArray = array();			// メニュー項目名
 	const SEARCH_WIDGET = 'ec_disp';			// 商品表示用ウィジェット
 	const DEFAULT_MENU_ID = 'ec_menu';			// デフォルトメニューID
 	const MAX_MENU_TREE_LEVEL = 5;			// メニュー階層最大数
@@ -50,6 +53,14 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 	const PARAM_CONTENT_ID = 'pcontent';	// コンテンツIDキー
 	const PARAM_CATEGORY_ID = 'category';	// カテゴリーIDキー
 	const DEFAULT_CATEGORY_COUNT = 2;	// デフォルトの商品カテゴリー選択可能数
+	const TREE_ITEM_HEAD = 'treeitem_';		// ツリー項目IDヘッダ
+	const WINDOW_ICON_FILE = '/images/system/window32.png';		// 同じウィンドウアイコン
+	const OTHER_WINDOW_ICON_FILE = '/images/system/other_window32.png';		// 別のウィンドウアイコン
+	const STOP_ICON_FILE = '/images/system/closed32.png';		// 停止中(項目非表示)アイコン
+	const TAG_ID_OPEN_OPTION = 'open_area';		// オプション領域表示用ボタンタグ
+	const TOOLTIP_OPEN_OPTION = 'オプションを表示';		// オプション領域表示用ボタンツールチップ
+	const TAG_ID_CLOSE_OPTION = 'close_area';				// オプション領域非表示用ボタンタグ
+	const TOOLTIP_CLOSE_OPTION = 'オプションを非表示';		// オプション領域非表示用ボタンツールチップ
 	
 	/**
 	 * コンストラクタ
@@ -63,10 +74,6 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		$this->db = new ec_menuDb();
 
 		// メニュー項目タイプ
-/*		$this->itemTypeArray = array(	array(	'name' => $this->_('Link'),			'value' => '0'),	// リンク
-										array(	'name' => $this->_('Folder'),		'value' => '1'),	// フォルダ
-										array(	'name' => $this->_('Text'),			'value' => '2'),	// テキスト
-										array(	'name' => $this->_('Separator'),	'value' => '3'));	// セパレータ*/
 		$this->itemTypeArray = array(	array(	'name' => $this->_('Folder'),		'value' => '1'),	// フォルダ
 										array(	'name' => $this->_('Separator'),	'value' => '3'));	// セパレータ
 
@@ -153,7 +160,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$localeText['label_lang'] = $this->_('Language');			// 言語
 			$localeText['label_new'] = $this->_('New');		// 新規
 			$localeText['label_item_type'] = $this->_('Item Type');		// 項目タイプ
-			$localeText['label_link_type'] = $this->_('Link Type');		// 表示方法
+			$localeText['label_link_type'] = $this->_('Action');		// 動作
 			$localeText['label_link_self'] = $this->_('Open page in the same window');		// 同ウィンドウで表示
 			$localeText['label_link_other'] = $this->_('Open page in the other window');		// 別ウィンドウで表示
 			$localeText['label_select_link'] = $this->_('Select Link Type');		// リンク先を選択
@@ -162,7 +169,7 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$localeText['label_input'] = $this->_('Input URL');	// URL任意設定
 			$localeText['label_page_id'] = $this->_('Page ID:');	// ページID：
 			$localeText['label_content'] = $this->_('General Contents:');	// 汎用コンテンツ：
-			$localeText['label_url'] = $this->_('URL');	// リンク先URL
+			$localeText['label_url'] = $this->_('URL');	// URL
 			$localeText['label_item_visible'] = $this->_('Item Control');	// 表示制御
 			$localeText['label_visible'] = $this->_('Visible');	// 公開
 			$localeText['msg_link_to_content'] = $this->_('Cotrol visible status linked to contents.');	// リンク先のコンテンツに連動
@@ -177,15 +184,16 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$localeText['msg_select_item'] = $this->_('Select menu item to edit.');		// 編集する項目を選択してください
 			$localeText['msg_select_del_item'] = $this->_('Select menu item to delete.');		// 削除する項目を選択してください
 			$localeText['msg_delete_item'] = $this->_('Delete selected item?');// 選択項目を削除しますか?
-			$localeText['label_menu_item_list'] = $this->_('Menu Item List');					// メニュー項目一覧
+			$localeText['label_menu_item_list'] = $this->_('Menu Definition');					// メニュー定義
+			$localeText['label_path'] = $this->_('Path:');					// 階層パス
 			$localeText['label_new'] = $this->_('New');					// 新規
 			$localeText['label_edit'] = $this->_('Edit');				// 編集
 			$localeText['label_delete'] = $this->_('Delete');			// 削除
 			$localeText['label_check'] = $this->_('Select');			// 選択
 			$localeText['label_name'] = $this->_('Name');			// 名前
 			$localeText['label_lang'] = $this->_('Language');			// 言語
-			$localeText['label_url'] = $this->_('URL');			// リンク先URL
-			$localeText['label_link_type'] = $this->_('Link Type');			// 表示方法
+			$localeText['label_url'] = $this->_('URL');			// URL
+			$localeText['label_link_type'] = $this->_('Division');			// 区分
 			$localeText['label_visible'] = $this->_('Visible');			// 公開
 			$localeText['label_operation'] = $this->_('Operation');		// 操作
 			$localeText['label_menu_layout'] = $this->_('Menu Layout');		// メニューレイアウト
@@ -222,8 +230,8 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		if ($ret) $this->menuDeviceType = $row['mn_device_type'];
 		
 		$act = $request->trimValueOf('act');
-		$parentId = $request->trimValueOf('parentid');		// 親メニューID取得
-		if ($parentId == '') $parentId = '0';
+		$this->parentId = $request->trimValueOf('parentid');		// 親メニューID取得
+		if ($this->parentId == '') $this->parentId = '0';
 		
 		if ($act == 'delete'){		// メニュー項目の削除
 			$listedItem = explode(',', $request->trimValueOf('seriallist'));
@@ -258,9 +266,11 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 				$this->gCache->clearCacheByWidgetType(self::WIDGET_TYPE_MENU);		// キャッシュをクリア
 				$this->gPage->updateParentWindow();// 親ウィンドウを更新
 			}
+		} else if ($act == 'selecttree'){		// メニューツリーから選択
+			$this->parentId = str_replace(self::TREE_ITEM_HEAD, '', $request->trimValueOf('treedest'));
 		} else if ($act == 'updatetree'){		// メニューツリーからの更新
-			$treeId = str_replace('treeitem_', '', $request->trimValueOf('treesrc'));
-			$treeParentId = str_replace('treeitem_', '', $request->trimValueOf('treedest'));
+			$treeId = str_replace(self::TREE_ITEM_HEAD, '', $request->trimValueOf('treesrc'));
+			$treeParentId = str_replace(self::TREE_ITEM_HEAD, '', $request->trimValueOf('treedest'));
 			$treePos = $request->trimValueOf('treepos');
 			$this->db->reorderMenuItem($this->menuId, $treeParentId, $treeId, $treePos);
 			
@@ -268,6 +278,16 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$this->gPage->updateParentWindow();// 親ウィンドウを更新
 		}
 		
+		// メニュー階層パスを取得
+		if (!empty($this->parentId)){
+			// 現在のメニュー項目からパスを作成
+			$this->parentIdArray = $this->getPath($this->menuId, $this->parentId);
+			
+			// メニュー項目を選択
+			$this->tmpl->setAttribute('select_tree_area', 'visibility', 'visible');
+			$this->tmpl->addVar("select_tree_area", "select_id", self::TREE_ITEM_HEAD . $this->parentId);		// 選択中のメニュー項目
+		}
+		
 		// 一覧の表示タイプを設定
 		if ($this->isMultiLang){		// 多言語対応の場合
 			$this->tmpl->setAttribute('show_multilang', 'visibility', 'visible');
@@ -285,11 +305,23 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		if (!$this->isExistsMenuItem) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');		// メニュー項目一覧
 		if ($fixedMode == '1') $this->tmpl->addVar("_widget", "sel_menu_id_disabled", 'disabled');			// メニューIDの選択可否
 		
+		// メニュー階層パスを作成
+		if (empty($this->parentIdArray)){
+			$path = '[ルート]';
+		} else {
+			$path = '<a href="#" onclick="selectTree(0);">[ルート]</a>';
+		}
+		for ($i = 0; $i < count($this->parentIdArray); $i++){
+			$path .= '&nbsp;/&nbsp;';
+			$path .= '<a href="#" onclick="selectTree(' . $this->parentIdArray[$i] . ');">' . $this->convertToDispString($this->parentNameArray[$i]) . '</a>';
+		}
+		
 		$this->tmpl->addVar("_widget", "tree", $treeMenu);		// メニューツリー
-		$this->tmpl->addVar("_widget", "parent_id", $parentId);		// メニュー項目親ID
+		$this->tmpl->addVar("_widget", "parent_id", $this->parentId);		// メニュー項目親ID
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
 		$this->tmpl->addVar('_widget', 'admin_url', $this->getUrl($this->gEnv->getDefaultAdminUrl()));// 管理者URL
 		$this->tmpl->addVar("_widget", "fixed_mode", $fixedMode);		// メニュー定義IDが固定かどうか
+		$this->tmpl->addVar("_widget", "path", $path);		// メニュー階層パス
 		
 		// ディレクトリを設定
 		$this->tmpl->addVar("_widget", "script_url", $this->getUrl($this->gEnv->getScriptsUrl()));
@@ -516,6 +548,19 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$this->createInputLangText($nameLangArray);
 		}
 		
+		// 拡張エリア制御
+		$openButton = $this->gDesign->createOptionButton(0/*表示ボタン*/, ''/*同画面*/, self::TOOLTIP_OPEN_OPTION, self::TAG_ID_OPEN_OPTION);
+		$this->tmpl->addVar('_widget', 'open_button', $openButton);
+		$this->tmpl->addVar('_widget', 'open_button_id', self::TAG_ID_OPEN_OPTION);
+		$closeButton = $this->gDesign->createOptionButton(1/*非表示ボタン*/, ''/*同画面*/, self::TOOLTIP_CLOSE_OPTION, self::TAG_ID_CLOSE_OPTION);
+		$this->tmpl->addVar('_widget', 'close_button', $closeButton);
+		$this->tmpl->addVar('_widget', 'close_button_id', self::TAG_ID_CLOSE_OPTION);
+		if ($this->isOpenOptionArea){
+			$this->tmpl->addVar('_widget', 'option_area_open', 'true');
+		} else {
+			$this->tmpl->addVar('_widget', 'option_area_open', 'false');
+		}
+		
 		// ### 入力値を再設定 ###
 		$this->tmpl->addVar("_widget", "name", $this->convertToDispString($name));		// 名前
 		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));		// タイトル(HTML可)
@@ -647,9 +692,8 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 			$itemCount = count($rows);
 			for ($i = 0; $i < $itemCount; $i++){
 				$row = $rows[$i];
-				
-				// デフォルト言語で名前を取得
-				$name = $this->getDefaultLangString($row['md_name']);
+				$id = $row['md_id'];
+				$name = $this->getDefaultLangString($row['md_name']);// デフォルト言語で名前を取得
 			
 				// 対応言語を取得
 				$lang = '';
@@ -657,6 +701,32 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 					$lang = $this->createLangImageList($row['md_name']);
 				}
 			
+				// ##### ツリーメニュー作成 #####
+				if ($row['md_type'] == 0){	// リンク項目のとき
+					$treeHtml .= '<li id="' . self::TREE_ITEM_HEAD . $id . '"><a href="#">' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
+				} else if ($row['md_type'] == 1){			// フォルダのとき
+					// サブメニュー作成
+					if (in_array($id, $this->parentIdArray)){		// メニュー階層パス上にある場合はフォルダを開く
+						$itemClass = 'jstree-open';
+						
+						$this->parentNameArray[] = $name;
+					} else {
+						$itemClass = 'jstree-closed';
+					}
+					$treeHtml .= '<li id="' . self::TREE_ITEM_HEAD . $id . '" rel="folder" class="' . $itemClass . '"><a href="#">' . $this->convertToDispString($name) . '</a>' . M3_NL;
+					$treeHtml .= '<ul>' . M3_NL;
+					$treeHtml .= $this->createTreeMenu($menuId, $id, $level + 1);
+					$treeHtml .= '</ul>' . M3_NL;
+					$treeHtml .= '</li>' . M3_NL;
+				} else if ($row['md_type'] == 2){			// テキストのとき
+					$treeHtml .= '<li id="' . self::TREE_ITEM_HEAD . $id . '"><a href="#">' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
+				} else if ($row['md_type'] == 3){			// セパレータのとき
+					$treeHtml .= '<li id="' . self::TREE_ITEM_HEAD . $id . '"><a href="#">' . '-----' . '</a></li>' . M3_NL;
+				}
+				
+				// 選択中のメニュー項目の内容のみ表示
+				if ($parantId != $this->parentId) continue;
+				
 				// メニュー項目タイプアイコン
 				$iconUrl = '';
 				switch ($row['md_type']){
@@ -681,26 +751,29 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 				}
 				$iconTag = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" border="0" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 		
-				$visible = '';
-				if ($row['md_visible']){
-					$visible = 'checked';
-				}
 				// リンクタイプ
-				$linkString = '';
-				switch ($row['md_link_type']){
-					case 0:			// 同ウィンドウで開くリンク
-						$linkString = $this->_('Self');		// 同
-						break;
-					case 1:			// 別ウィンドウで開くリンク
-						$linkString = $this->_('Other');	// 別
-						break;
-				}
-				// 項目選択のラジオボタンの状態
-				$serial = $row['md_id'];
-				$selected = '';
-				if ($serial == $this->serialNo){
-					$selected = 'checked';
+				$linkIconTag = '';
+				if ($row['md_visible']){			// メニュー項目表示の場合
+					switch ($row['md_link_type']){
+						case 0:			// 同ウィンドウで開くリンク
+							$iconUrl = $this->gEnv->getRootUrl() . self::WINDOW_ICON_FILE;
+							$iconTitle = $this->_('Show in self window');		// 同じウィンドウで表示
+							$linkIconTag = '<img src="' . $this->getUrl($iconUrl) . '" alt="' . $iconTitle . '" title="' . $iconTitle . '" rel="m3help" />';
+							break;
+						case 1:			// 別ウィンドウで開くリンク
+							$iconUrl = $this->gEnv->getRootUrl() . self::OTHER_WINDOW_ICON_FILE;
+							$iconTitle = $this->_('Show in other window');		// 別のウィンドウで表示
+							$linkIconTag = '<img src="' . $this->getUrl($iconUrl) . '" alt="' . $iconTitle . '" title="' . $iconTitle . '" rel="m3help" />';
+							break;
+					}
+				} else {
+					$iconUrl = $this->gEnv->getRootUrl() . self::STOP_ICON_FILE;// 停止中(項目非表示)アイコン
+					$iconTitle = $this->_('Hidden item');		// 非表示項目
+					$linkIconTag = '<img src="' . $this->getUrl($iconUrl) . '" alt="' . $iconTitle . '" title="' . $iconTitle . '" rel="m3help" />';
 				}
+				
+				// 更新用シリアル番号
+				$serial = $id;
 		
 				// リンクURLを作成
 				$parsedParam = parseUrlParam($row['md_param']);
@@ -709,20 +782,18 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 				} else {
 					$url = $this->gPage->getDefaultPageUrlByWidget(self::SEARCH_WIDGET, $row['md_param']);
 					$linkUrlStr = str_replace($this->gEnv->getRootUrl(), '...', $url);		// 表示テキスト
-					$linkUrlStr = '<a href="#" onclick="showUrl(\'' . $this->getUrl($url, true) . '\');">' . $this->convertToDispString($linkUrlStr) . '</a>';
+					$linkUrlStr = '<a href="#" onclick="previewInOtherWindow(\'' . $this->getUrl($url, true) . '\');">' . $this->convertToDispString($linkUrlStr) . '</a>';
 				}
 				
 				$itemRow = array(
 					'index' => $index,													// 行番号
 					'serial' => $this->convertToDispString($serial),			// シリアル番号
-					'id' => $this->convertToDispString($row['md_id']),			// ID
+					'id' => $this->convertToDispString($id),			// ID
 					'name' => $this->convertToDispString($name),		// 名前
 					'lang'		=> $lang,			// 言語
 					'item_type' => $iconTag,											// メニュー項目タイプアイコン
-					'link_type' => $linkString,											// リンクタイプ
+					'link_type' => $linkIconTag,											// リンクタイプ
 					'link_str' => $linkUrlStr,											// リンクURL
-					'visible' => $visible,											// メニュー項目表示制御
-					'selected' => $selected,												// 項目選択用ラジオボタン
 					'label_edit_content' => $this->_('Edit Content')				// コンテンツを編集
 				);
 
@@ -739,26 +810,42 @@ class admin_ec_menuMenudefWidgetContainer extends admin_ec_menuBaseWidgetContain
 		
 				// シリアル番号を保存
 				$this->serialArray[] = $serial;
-				
-				// ##### ツリーメニュー作成 #####
-				if ($row['md_type'] == 0){	// リンク項目のとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
-				} else if ($row['md_type'] == 1){			// フォルダのとき
-					// サブメニュー作成
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '" rel="folder" class="jstree-open"><a href="#">' . $this->convertToDispString($name) . '</a>' . M3_NL;
-					$treeHtml .= '<ul>' . M3_NL;
-					$treeHtml .= $this->createTreeMenu($menuId, $row['md_id'], $level + 1);
-					$treeHtml .= '</ul>' . M3_NL;
-					$treeHtml .= '</li>' . M3_NL;
-				} else if ($row['md_type'] == 2){			// テキストのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . $this->convertToDispString($name) . '</a></li>' . M3_NL;
-				} else if ($row['md_type'] == 3){			// セパレータのとき
-					$treeHtml .= '<li id="treeitem_' . $row['md_id'] . '"><a href="#">' . '-----' . '</a></li>' . M3_NL;
-				}
 			}
 		}
 		return $treeHtml;
 	}
+	/**
+	 * メニュー階層パス取得
+	 *
+	 * @param string $menuId		メニューID
+	 * @param int    $parantId		親メニュー項目ID
+	 * @param int    $level			階層数
+	 * @return array				メニュー項目IDの配列
+	 */
+	function getPath($menuId, $parantId, $level = 0)
+	{
+		static $pathArray = array();
+		
+		// メニューの階層を制限
+		if ($level >= self::MAX_MENU_TREE_LEVEL) return $pathArray;
+		
+		if (empty($parantId)) return $pathArray;		// メニューIDが0のときは終了
+		
+		// メニューパス追加
+		$pathArray[] = $parantId;
+		
+		// メニュー項目情報を取得
+		$ret = $this->db->getMenuItem($parantId, $row);
+		if ($ret){
+			// 親メニュー項目のパスを取得
+			$this->getPath($menuId, $row['md_parent_id'], $level + 1);
+			
+			if ($level == 0) $pathArray = array_reverse($pathArray);		// パスを反転
+			return $pathArray;
+		} else {
+			return $pathArray;
+		}
+	}
 	/**
 	 * メニュー項目削除
 	 *
