@@ -276,8 +276,8 @@ function make_line_rules($str)
 	static $pattern, $replace;
 
 	if (! isset($pattern)) {
-		$pattern = array_map(create_function('$a',
-			'return \'/\' . $a . \'/\';'), array_keys($line_rules));
+//		$pattern = array_map(create_function('$a', 'return \'/\' . $a . \'/\';'), array_keys($line_rules));
+		$pattern = array_map(function($a){ return '/' . $a . '/'; }, array_keys($line_rules));
 		$replace = array_values($line_rules);
 		unset($line_rules);
 	}
@@ -347,8 +347,9 @@ function make_heading(& $str, $strip = TRUE)
 
 	// Cut footnotes and tags
 //	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace($NotePattern, '', $str)));
-	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace_callback($NotePattern, create_function('$matches','return;'), $str)));		// PHP5.5用修正
-	
+//	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace_callback($NotePattern, create_function('$matches','return;'), $str)));		// PHP5.5用修正
+	if ($strip === TRUE) $str = strip_htmltag(make_link(preg_replace_callback($NotePattern, function($matches){ return ''; }, $str)));
+
 	return $id;
 }
 
@@ -442,13 +443,13 @@ function password_form()
 					$body .= '<form method="post" class="form form-inline" role="form">' . M3_NL;
 					$body .= '<input type="hidden"   name="pass" />' . M3_NL;
 					$body .= '<div class="form-group"><label>' . $_msg_password . ':<input type="password" class="form-control" name="password" size="12" /></label>' . M3_NL;
-					$body .= '<input type="submit" class="button btn" value="' . $_btn_submit . '" onclick="this.form.pass.value = hex_md5(this.form.password.value);" /></div>' . M3_NL;
+					$body .= '<input type="submit" class="button btn" value="' . $_btn_submit . '" onclick="this.form.pass.value = hex_md5(this.form.password.value); this.form.password.value = \'\';" /></div>' . M3_NL;
 					$body .= '</form>' . M3_NL;
 				} else {
 					$body .= '<form method="post" class="form">' . M3_NL;
 					$body .= '<input type="hidden"   name="pass" />' . M3_NL;
 					$body .= '<label>' . $_msg_password . ':<input type="password" name="password" size="12" /></label>' . M3_NL;
-					$body .= '<input type="submit" class="button" value="' . $_btn_submit . '" onclick="this.form.pass.value = hex_md5(this.form.password.value);" />' . M3_NL;
+					$body .= '<input type="submit" class="button" value="' . $_btn_submit . '" onclick="this.form.pass.value = hex_md5(this.form.password.value); this.form.password.value = \'\';" />' . M3_NL;
 					$body .= '</form>' . M3_NL;
 				}
 			} else {		// パスワード認証でないとき
